==> haskell-yesod-form-1.6.6-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.6.6
id: yesod-form-1.6.6-4qWZybKcdO38na85WHdPgt
key: yesod-form-1.6.6-4qWZybKcdO38na85WHdPgt
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
abi: dfe41cd9f557b1774380730cfb0f266f
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-form-1.6.6
hs-libraries: HSyesod-form-1.6.6-4qWZybKcdO38na85WHdPgt
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    containers-0.6.0.1 data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    email-validate-2.3.2.11-ERGbRnZUwr48XHt00rn7dV
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    persistent-2.10.1-3og9MAC29gi7KTjTVnXGs7
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    shakespeare-2.0.21-2LOxZglsNEK6waTgvreNvH text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    xss-sanitize-0.3.6-5Bg9vxiQErB9FeMVIRu8G6
    yesod-core-1.6.16-7HNIPMfL0aZE7C4w2n8DAf
    yesod-persistent-1.6.0.2-9j4Zpk50X513EAWaADuPmu
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.6.6-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.6.6
id: yesod-form-1.6.6-CmSzam1rcu43KMAMgrwwpD
key: yesod-form-1.6.6-CmSzam1rcu43KMAMgrwwpD
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
abi: 665cb55685a09a80e4e9abf1fcf348ca
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-form-1.6.6
hs-libraries: HSyesod-form-1.6.6-CmSzam1rcu43KMAMgrwwpD
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    containers-0.6.0.1 data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    email-validate-2.3.2.11-ERGbRnZUwr48XHt00rn7dV
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    persistent-2.10.1-BsiVA8EaffVF5nNTPbHD98
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    shakespeare-2.0.21-2LOxZglsNEK6waTgvreNvH text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    xss-sanitize-0.3.6-5Bg9vxiQErB9FeMVIRu8G6
    yesod-core-1.6.16.1-6XGVgy2VfEf9Fp8YrJXF1T
    yesod-persistent-1.6.0.2-8iRviuCN9nIPw5742KRT4
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
